@@ -6,7 +6,7 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '1.016_05';
+our $VERSION = '1.016_06';
 
 use Clone                  qw( clone );
 use List::MoreUtils        qw( any );
@@ -753,20 +753,22 @@ sub __on_table {
         elsif ( $custom eq $customize{'print_table'} ) {
             my $cols_sql = " ";
             if ( $sql->{select_type} eq '*' ) {
-                $cols_sql = " " . "*";
+                if ( $self->{info}{multi_tbl} eq 'join' ) {                            # ?
+                    $cols_sql .= join( ', ', map { $qt_columns->{$_} } @$pr_columns ); # ?
+                }                                                                      # ?
+                else {
+                    $cols_sql .= "*";
+                }
             }
             elsif ( $sql->{select_type} eq 'chosen_cols' ) {
-                $cols_sql = " " . join( ', ', @{$sql->{quote}{chosen_cols}} );
+                $cols_sql .= join( ', ', @{$sql->{quote}{chosen_cols}} );
             }
             elsif ( @{$sql->{quote}{aggr_cols}} || @{$sql->{quote}{group_by_cols}} ) {
-                $cols_sql = " " . join( ', ', @{$sql->{quote}{group_by_cols}}, @{$sql->{quote}{aggr_cols}} );
-            }
-            else { #
-                $cols_sql = " " . "*";
-            }
-            if ( $cols_sql eq "*" && $sql->{quote}{join_col_stmt} ) { # ?
-                $cols_sql = " " . $sql->{quote}{join_col_stmt};
+                $cols_sql .= join( ', ', @{$sql->{quote}{group_by_cols}}, @{$sql->{quote}{aggr_cols}} );
             }
+            #else {
+            #    $cols_sql .= "*";
+            #}
             my $select .= "SELECT" . $sql->{quote}{distinct_stmt} . $cols_sql;
             $select .= " FROM " . $sql->{quote}{table};
             $select .= $sql->{quote}{where_stmt};
@@ -824,13 +826,13 @@ sub __commit_sql {
     local $| = 1;
     print $self->{info}{clear_screen};
     print 'Database : ...' . "\n" if $self->{opt}{table}{progress_bar};
-    #if ( $self->{info}{db_driver} eq 'SQLite' ) {
-    #    $dbh->disconnect();
-    #    my $db = $sql->{print}{db};
-    #    my $connect_parameter = $self->__prepare_connect_parameter( $db );
-    #    my $obj_db = App::DBBrowser::DB->new( $self->{info}, $self->{opt} );
-    #    $dbh = $obj_db->get_db_handle( $db, $connect_parameter );
-    #}
+    if ( $self->{info}{db_driver} eq 'SQLite' ) {
+        $dbh->disconnect();
+        my $db = $sql->{print}{db};
+        my $connect_parameter = $self->__prepare_connect_parameter( $db );
+        my $obj_db = App::DBBrowser::DB->new( $self->{info}, $self->{opt} );
+        $dbh = $obj_db->get_db_handle( $db, $connect_parameter );
+    }
     my $transaction;
     eval { $transaction = $dbh->begin_work } or do { $dbh->{AutoCommit} = 1; $transaction = 0 };
     my $rows_to_execute = [];
